@@ -28,7 +28,7 @@
 #include "keyinfodialog.h"
 #include "keyservers.h"
 #include "keytreeview.h"
-#include "kgpg_debug.h"
+#include "kgpg_general_debug.h"
 #include "kgpg.h"
 #include "kgpgchangekey.h"
 #include "kgpgkeygenerate.h"
@@ -89,7 +89,7 @@
 #include <QApplication>
 #include <QClipboard>
 #include <QDBusConnection>
-#include <QDebug>
+
 #include <QDesktopServices>
 #include <QDir>
 #include <QEvent>
@@ -608,7 +608,7 @@ void KeysManager::slotGenerateKeyDone(KJob *job)
 		page->kURLRequester1->setUrl(KGpgRevokeDialog::revokeUrl(genkey->getName(), email));
 
 		const QString fingerprint(genkey->getFingerprint());
-		page->TLid->setText(QLatin1String( "<b>" ) + fingerprint.right(8) + QLatin1String( "</b>" ));
+		page->TLid->setText(QLatin1String( "<b>" ) % fingerprint.rightRef(8) % QLatin1String( "</b>" ));
 		page->LEfinger->setText(fingerprint);
 		page->CBdefault->setChecked(true);
 		page->show();
@@ -925,10 +925,10 @@ void KeysManager::slotAddPhoto()
 	"if you use a very large picture, your key will become very large as well. The size should not exceed 6 KiB. "
 	"An image size of around 240x288 is a good size to use.");
 
-	if (KMessageBox::warningContinueCancel(0, mess) != KMessageBox::Continue)
+    if (KMessageBox::warningContinueCancel(nullptr, mess) != KMessageBox::Continue)
 		return;
 
-	QString imagepath = QFileDialog::getOpenFileName(0, QString(), QString(), QLatin1String( "image/jpeg" ));
+    QString imagepath = QFileDialog::getOpenFileName(nullptr, QString(), QString(), QLatin1String( "image/jpeg" ));
 	if (imagepath.isEmpty())
 		return;
 
@@ -1048,7 +1048,7 @@ void KeysManager::slotAddressbookSearchResult(KJob *job)
 void KeysManager::slotManpage()
 {
 	KToolInvocation::startServiceByDesktopName(QLatin1String("khelpcenter"),
-			QLatin1String("man:/gpg"), 0, 0, 0, QByteArray(), true);
+            QLatin1String("man:/gpg"), nullptr, nullptr, nullptr, QByteArray(), true);
 }
 
 void KeysManager::slotTip()
@@ -2806,13 +2806,15 @@ KeysManager::slotOpenKeyUrl()
 		return;
 
 	QString url = servers.first();
+	const QString idUC = id.toUpper();
+	const QString idLC = id.toLower();
 
-	url.replace(QLatin1String("$$ID8$$"), id.right(8).toUpper());
-	url.replace(QLatin1String("$$ID16$$"), id.toUpper());
-	url.replace(QLatin1String("$$FPR$$"), id.toUpper());
-	url.replace(QLatin1String("$$id8$$"), id.right(8).toLower());
-	url.replace(QLatin1String("$$id16$$"), id.toLower());
-	url.replace(QLatin1String("$$fpr$$"), id.toLower());
+	url.replace(QLatin1String("$$ID8$$"), idUC.right(8));
+	url.replace(QLatin1String("$$ID16$$"), idUC.right(16));
+	url.replace(QLatin1String("$$FPR$$"), idUC);
+	url.replace(QLatin1String("$$id8$$"), idLC.right(8));
+	url.replace(QLatin1String("$$id16$$"), idLC.right(16));
+	url.replace(QLatin1String("$$fpr$$"), idLC);
 
 	new KRun(QUrl(url), this);
 }
@@ -2828,7 +2830,7 @@ KeysManager::clipDecrypt()
 		return;
 	}
 
-	KgpgEditor *kgpgtxtedit = new KgpgEditor(this, imodel, 0);
+    KgpgEditor *kgpgtxtedit = new KgpgEditor(this, imodel, nullptr);
 	kgpgtxtedit->setAttribute(Qt::WA_DeleteOnClose);
 	connect(this, &KeysManager::fontChanged, kgpgtxtedit, &KgpgEditor::slotSetFont);
 	kgpgtxtedit->m_editor->setPlainText(cliptext);
@@ -2846,7 +2848,7 @@ KeysManager::clipSign()
 		return;
 	}
 
-	KgpgEditor *kgpgtxtedit = new KgpgEditor(this, imodel, 0);
+    KgpgEditor *kgpgtxtedit = new KgpgEditor(this, imodel, nullptr);
 	kgpgtxtedit->setAttribute(Qt::WA_DeleteOnClose);
 	connect(kgpgtxtedit->m_editor, &KgpgTextEdit::verifyFinished, kgpgtxtedit, &KgpgEditor::closeWindow);
 
